@@ -4,7 +4,7 @@ from typing import Dict, Type, TypeVar, List, Optional
 from requests import get
 from tdw.output_data import OutputData, Transforms, Rigidbodies, Bounds, Images, SegmentationColors, Volumes, Raycast, \
     CompositeObjects, CameraMatrices, Environments, Overlap, Version, StaticRobot, Robot, Magnebot, NavMeshPath, \
-    ScreenPosition, AudioSources
+    ScreenPosition, AudioSources, AvatarKinematic, ImageSensors
 
 
 T = TypeVar("T", bound=OutputData)
@@ -26,7 +26,9 @@ __OUTPUT_IDS: Dict[Type[OutputData], str] = {Transforms: "tran",
                                              Magnebot: "magn",
                                              NavMeshPath: "path",
                                              ScreenPosition: "scre",
-                                             AudioSources: "audi"}
+                                             AudioSources: "audi",
+                                             AvatarKinematic: "avki",
+                                             ImageSensors: "imse"}
 
 
 def get_data(resp: List[bytes], d_type: Type[T]) -> Optional[T]:
@@ -60,5 +62,5 @@ def check_version(module: str = "magnebot") -> None:
     v_remote = loads(get(f"https://pypi.org/pypi/{module}/json").content)["info"]["version"]
 
     if v_remote != v_local:
-        print(f"You have {module} v{v_local} but version v{v_local} is available. "
+        print(f"You have {module} v{v_local} but version v{v_remote} is available. "
               f"To upgrade:\npip3 install {module} -U")
